@@ -235,7 +235,6 @@ AccountNumberCheck::Result method_24(const int *account, int *weight) {
 	account_buf[i] = account[i];
     }
 
-    int start=0;
     if (2 < account_buf[0] && 7 > account_buf[0])
 	account_buf[0] = 0;
     if (9 == account_buf[0]) {
@@ -247,12 +246,13 @@ AccountNumberCheck::Result method_24(const int *account, int *weight) {
     }
 
     // check how many leading "0", shift weight to right
+    //int start=0;
     std::string weightString = "";
     for (int i=0; i<10; i++) {
 	if (0 == account_buf[i])
 	    weightString += "0";
 	else {
-	    start = i;
+	    //start = i;
 	    break;
 	}
     }
